bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 4. Aventiure
___________________________________________________
| ### EU NAHTEN> vremdiv mære in Gvnthers lant ### von boten di in verre wrden dar gesant ### von vnchvnden rechen di in trvogen haz ### do si die [297a] rede vernamen leit was in wærliche daz ### Die wil ich iv nennen ez was Livdeger ### vozer Sahsen lande ein richer fvrste her ### vn– ovch von Tenemarche der kvnec Livdegast ### die brahten in ir reise vil manegn herlichn gast
###### 139 | ### Ir boten chomn waren in Gvnthers lant ### di sine widerwinnen waren dar gesant ### do vraget man der mære di vnchvnden man ### man hiez di boten balde ce hove fvr den kvnec gan
| ### <Der> grvozte si vil scone er sprach sit willechomn ### wer ivch her hab gesendent desn han ich niht vernomn ### daz svlt ir lazen hoeren sprach der kvnec gvot ### do vorhten si vil sere den grimmen Gvnthers mvot
###### 141 | ### Welt ir kvnec erlovben daz wir iv mære sagn ### div wir iv da bringen sone svl wir niht verdagn ### wir nennen iv di herren di vns her habent gesant ### Livdgast vnd Livdger di wellent svochen her enlant
###### 142 | ### Ir habt ir zorn verdienet ia horten wir wol daz ### daz iv di herrn beide tragent grozen haz ### si wellent herverten ce Wormez an den Rin ### in hilfet vil der degene daz wizzet vof di triwe min
###### 143 | ### Inre zwelf wochen div reise mvoz gescehn ### habt ir iht gvoter friwende daz lazet <balde> sehn ### di iv <vriden> helfen di bvrge vn– iwer lant ### hie wirt von in verhovwen vil manec helm vnd rant
###### 144 | ### Oder welt ir mit in dingen so enbietet ez in dar ### sone ritent iv so nahen niht di manegen scar ### der iwer starchen viende v^f hercenlichiv leit ### da von verderben mvezen vil gvote riter gemeit
| ### <Nv> bîtet eine wile sprach der kvnec gvot ### vnz ich mich baz versinne ich chvend iv minen mvot ### han ich getriwer iemen dine sol ich niht verdagn ### disiv starchen mære sol ich minen friwenden chlagn
###### 146 | ### Gvnthere dem vil richen wart leide genvoch ### di rede er tovgenlichen insime hercen trvoch ### er hiez gewinnen Hagenen vn– ander sine man ### vn– bat ovch harte balde ce hove nach Gernote gan
###### 147 | ### Do chomen di bestn swaz man der da vant ### er sprach man wil vns svochen her in vnser lant ### mit starchen herverten daz lat iv wesen leit ### des antwrte Gernot ein riter chven vnt gemeit
###### 148 | ### Daz wer et wir mit swerten so sprach Gernot ### da sterbent wan di veigen di lazen ligen tot ### dar vmb ich niht vergezen mach der eren min ### di vnsern viande svln vns willechomn sin
| ### <Do> sprach von Tronege Hagne [297b] daz endvnchet mich niht gvot ### Livdgast vnt Livdger di tragent vbermvot ### wir mvgen vns niht besenden in so chvrcen tagn ### so sprach der chvene reche wan mvgt irz Sivride sagn
###### 150 | ### Die boten herbergen hiez man in di stat ### swie vient man in wære vil scone ir pflegn bat ### Gvnther der riche daz was wol getan ### vnz er revant an friwenden wer im da <wolde> gestan
| ### Dem kvnege in sinen sorgen was idoch vil leit ### do sah in trvorende ein riter vil gemeit ### der niht mohte wizzen waz im was gescehen ### do bat er im der mære den kvnec Gvnther veriehen
###### 152 | ### Mich nimt des <michel> wnder sprach do Sivrit ### wie habt ir so vercheret di vroelichen sit ### der ir mit vns nv lange habt alher gepflegn ### des antwrt im do Gvnther der vil cierliche degn
###### 153 | ### <· ane> mag ich allen livten di swære niht gesagn ### di ich mvoz tovgenliche in mime hercen tragn ### man sol stæten vriwenden chlagen hercen not ### div Sivrides varwe wart do bleich vnd rot
###### 154 | ### Er sprach zvo dem kvnege ine han iv niht verseit ### ich sol iv helfen wenden elliv iwer leit ### welt ir vriwent svochen der sol ich einer sin ### vnt trwoez wol volbringen mit eren an daz ende min
| ### <Nv> lon iv got her Sivrit div rede dvnchet mich gvt ### vn– ob mir nimmer helfe iwer ellen getvot ### ich frev mich doch der mære daz ir mir sit so holt ### leb ich decheine wile ez wirdet vmb ivch wol versolt
###### 156 | ### Ich wil ivch lazen hoeren war vmb ich trvorec stan ### von botn miner viende ich daz vernomn han ### daz si mich wellen svochen mit herverten hie ### daz getaten vns noch degene her zvo disen landen nie
| ### <Daz> lat ivch ahten ringe sprach do Sivrit ### vnt senftet iwerem mvote tvot des ich ivch bit ### lat mich iv erwerben ere vnde frvmn ### vn– bittet iwer degene daz si iv ovch ce helfe chvmn
###### 158 | ### Swenne iwer starchen viende zir helfe moehten han ### drizech tvsent degene so wold ich si bestan ### vn– het ich niwan tvsent des lat ivch an mich ### do sprach der kvnec Gvnther daz dien ich immer vm dich
###### 159 | ### <· o> heizet mir gewinnen tvsent iwer man ### sit daz ich der minen bi mir niht enhan ### niwan zwelf rechen so wer ich iwer lant ### iv sol mit triwen dienen immer Sivrids hant
###### 160 | ### Des sol vns helfen Hagne vn– ovch Oertwin ### Danchwart vnd Sindolt di liebn rechen din ### ovch sol da mit riten Volker der chvene man ### der sol den vanen fveren baz ichs niemn engan
###### 161 | ### Vnt lat di boten riten heim in ir herrn lant ### daz si vns sehen sciere daz tvo man in bechant [298a] ### so daz vnser bverge mvezen vride han ### do hiez der kvnec besenden beide mage vnd man
###### 162 | ### <· ie> boten Livdegers ce hove giengen do ### daz si ce lande solden des waren si vil vro ### do bot in riche gabe Gvnther der kvnec gvot ### vn– scvof in sin geleite des stvont in hohe der mvot
###### 163 | ### Nv sagt sprach do Gvnther den starchen <vienden> min ### si mvgen mit ir reise wol da heime sin ### welln aber si mich svochen her in miniv lant ### mirn ce rinne miner vriwende in wirt arbeit erchant
###### 164 | ### Den boten riche gabe man do fver trvoch ### der het in ce gebene Gvnther genvoch ### dine torstn versprech di Livdgers man ### do si vrlovp genamen si schieden vroeliche dan
###### 165 | ### <· o> di boten warn ce Tenemarche chomn ### vnt der kvnec Livdgast hete daz vernomn ### wie si <von> Rine chômn als im daz wart geseit ### ir starchez vbermveten daz was im wærlichen leit
###### 166 | ### Si sagten daz si heten vil manegen chvenen man ### ovch sahen si dar vnder einen rechen stan ### der was geheizen Sivrit ein helt voz Niderlant ### ez leidete Livdegaste als er daz mære rehte ervant
###### 167 | ### Do di von Tenemarche dizze horten sagn ### do ilten si der friwente deste mer beiagn ### vnz daz her Livdegast siner chvenen man ### zweinzech tvsent degene zvo siner reise gewan
| ### <Do> besant ovch sich von Sachsen der kvnec Livdger ### vnze si vierzech <tvsent> heten vnde mer ### mit den si wolden riten in Bvrgonden lant ### do het ovch sich hie heime der chvnech Gvnther besant
###### 169 | ### mit den sinen magen vn– siner brvoder man ### die si wolden fveren dvrch vrlivge dan ### vn– ovch di Hagenen rechen des gie den helden not ### dar vmbe mvosen degene sider chiesen den tot
###### 170 | ### Si vlizzen sich der reise do si wolden dan ### den vanen mvose leiten Volker der chvene man ### also si wolden riten von Wormez vber Rin ### Hagene von Tronege der mvose scarmeister sin
###### 171 | ### Da mite reit ovch Sindolt vnd Hvonolt ### di wol gedienen chvnden daz Gvnthers golt ### Danchwart Hagenen brvoder vn– ovch Oertwin ### di mohten wol mit ern inder herverte sin
###### 172 | ### <· er> kvnec nv sit hie heime sprach do Sivrit ### sit daz iwer rechen mir wellent volgen mit ### belibet bi den frovwen vn– traget hohen mvot ### ich tre iv wol behveten beidiv ere vnde gvot
###### 173 | ### Die ivch da wolden svochen ce Wormez an [298b] den Rin ### daz wil ich wol behveten si mvegen da heime sin ### wir svlen in geriten so nahen in ir lant ### daz in ir vbermveten <werde> in sorgn erwant
| ### <Von> Rine si dvrch Hessen mit ir helden riten ### gegen Sahsen lande da wart sit gestriten ### mit rovbe vn– ovh mit brande wosten si daz lant ### daz ez den fversten beiden wart mit arbeit bechant
###### 175 | ### Si chomen v^f di marche di chnehte zogten dan ### Sivrit der vil starche vragen des began ### wer sol des gesindes vns nv hveten hie ### iane wart <den> Sahsen geriten schedlicher nie
###### 176 | ### Si sprachen lat di tvmben hveten v^f den wegn ### den chvenen Danchwarten der ist ein sneller degn ### wir vliesen desteminre von Livdgers man ### lat in vn– Oertewinen hie di nah hvote han
###### 177 | ### So wil ich selbe riten sprach Sivrit der degen ### vn– wil der warte gegen den vienden pflegn ### vnz ich rehte ervinde wa di rechen sint ### do wart gewafent sciere der scoenen Siglinden chint
###### 178 | ### Daz volch bevalch er Hagenen do er wolde dan ### vn– Gernote dem vil chvenen man ### do reit er eine dannen in der Sahsen lant ### des wart von im verhovwen des tages manech helm bant
###### 179 | ### Do sah er her daz groze daz v^f dem <velde> lach ### daz wider siner helfe mit vnfvoge wach ### des was wol viercech tvsent oder dannoch baz ### Sivrit in hohem mvote sach vil vroeliche daz
###### 180 | ### <· o> het ovch sich ein reche gein den vienden dar ### erhaben v^f di warte der was ce vlize gar ### den sach der herre Sivrit vn– in der chvene man ### ietweder do des andern mit nide hveten began
###### 181 | ### Ich sag iv wer <der> wære der der warte pflach ### ein liehter scilt von golde im vor der hende lach ### ez was der kvnec Livdegast der hvote siner schar ### dirre gast vil edele spranchte vil herlichen dar
###### 182 | ### Nv het ovch in her Livdgast vientlich erchorn ### ir ross si namen beide cen siten mit <den> sporn ### si neigten v^f di scilde di scefte mit ir chraft ### des wart der kvnec riche mit grozen sorgen behaft
###### 183 | ### Div ross nach stiche trvogen. div richen kvnges kint ### beide fvr ein ander sam si wæte ein wint ### mit zovmen wart gewendet vil riterliche dan ### mit swerten ez versvochten die zwene grimmige man
| ### Do <slvoch> der herre Sivrit daz al daz velt erdoz ### do stovb vz dem helme sam von brenden groz ### die viwer roten vanchen von des heldes hant ### ir ietweder den sinen an dem andern vant
###### 185 | ### Ovch slvg im her Livdgast vil manegen grim [299a] men slach ### ir ietweders ellen v^f schilden vaste lach ### do heten dar gehvetet wol drizech siner man ### ê daz im di choemen den sig doch Sivrit gewan
###### 186 | ### mit drien starchen wnden di er dem kvnge slvoch ### dvrch eine wize brvnne div was gvot genvoch ### daz swert an sinen ekken braht voz wnden blvot ### des mvose der kvnec Livdegast. habn trvorigen mvot
| ### <Er> bat sich lebn lazen vn– bot im siniv lant ### vn– sagt im daz er wære Livdegast genant ### do chomen sine rechen di heten wol gesehen ### waz da von in beiden v^f der warte was gescehn
###### 188 | ### Er wolde infveren dannen do wart er an gerant ### von drizech sinen mannen do werte des heldes hant ### sinen richen gisel mit vngefvegen slegen ### sit tet scaden mere der vil zierliche degen
###### 189 | ### Die drizech er ce tode vil werliche slvoch ### er liez ir lebn einen balde er reit genvoch ### vn– sagte hin div mære waz hie was gescehen ### ovch mohte mans der warheit an sime rotem helme sehen
| ### <Den> von Tenemarche was vil grimme leit ### ir herre was gevangen do in daz wart geseit ### man sagt ez sinem brvoder toben er began ### von vngefvegem zorne wand im was leide getan
###### 191 | ### Livdegast der reche was gefveret dan ### von Sivrids gewalte zvo Gvnthers man ### er bevalch in Hagenen do in daz wart geseit ### daz ez der kvnech wære do was in mæzliche leit
| ### <Man> hiez den Bvrgonden ir vanen binden an ### wol v^f sprach Sivrit hie wirt mêr getan ### ê sich der tach verende sol ich habn den lip ### daz mvot in Sahsen lande vil manech wætlichez wip
###### 193 | ### Ir helde von dem Rine ir svlt min nemn war ### ich chan ivch wol geleiten in <Livdegers> scar ### so seht ir helme hovwen von gvoter helde hant ### ê daz wir wider wenden iv wirdet sorge bechant
| ### <Cen> rossen gahte Gernot vn– sine man ### den vanen zvchte balde der starche spileman ### Volker der herre do reit er vor der scar ### do was ovch daz gesinde ce strite herlichen gar
###### 195 | ### Si fvorten doch niht mêre niwan tvsent man ### dar vber zwelf rechen stieben do began ### di molten von den strazen si riten vber lant ### da sah man von in scinen vil manegen herlichen rant
| ### <Do> waren ovch di Sahsen mit ir scharn chomn ### mit swerten wol gewachsen daz han ich sit vernomn ### div swert div sniten sere den [299b] helden an der hant ### do wolden si den gestn weren bverge vnd lant
###### 197 | ### Der herrn scarmeister daz volch do fverte dan ### do was ovch chomn Sivrit mit den sinen man ### di er mit im brahte vozer Niderlant ### des tages wart instvrme vil manech plvotigiv hant
###### 198 | ### Sindolt vnd Hvnolt vn– ovch Gernot ### di slvogn in dem strite vil manegen helt tot ### ê si daz reht erfvnden wie chvene was ir lip ### daz mvose sit beweinen vil manech edel wip
###### 199 | ### Volker vnd Hagne vn– ovch Oertwin ### di lascten ime strite vil maneges helmes schin ### mit vliezendem blvote di stvorm chvene man ### da wart von Danchwarte vil michel <wnder> getan
| ### <Die> von Tenemarche versvochten wol ir hant ### do horte man von hvrte. erdiezen manegen rant ### vn– ovch von scærpfen swerten der man da vil geslvoch ### di stritchvenen Sahsen taten scaden da genvoch
###### 201 | ### Do di von Bvrgonden drvngen in den strit ### von in wart erhovwen vil manech <wnde> wit ### do sah man vber sætele fliezen daz blvot ### svs wrben nach den eren di riter chvene vnde gvot
###### 202 | ### Man horte da lvote erhellen den helden an der hant ### div vil scarpfen wafen do di von Niderlant ### drvngen nach ir herren in di herten scar ### si chomn degenliche mit samt Sivride dar
###### 203 | ### Volgen der von Rine niemn man im sach ### man mohte chiesen vliezen den blvtigen bach ### dvrch di liehten helme von Sivrids hant ### vnz er Livdegern vor sinen her gesellen vant
###### 204 | ### Dri widerchere het er nv genomn ### dvrch daz her anz ende nv was Hagene chomn ### der half im wol ervollen in stvorme sinen mvot ### des tages mvose ersterben vor in manech riter gvot
| ### <Do> der starche Livdger Sivriden vant ### vn– daz er also hohe trvog an siner hant ### den gvoten Balmvngen vn– ir so manegen slvoch ### des wart der herre zornech vn– grimmich genvoch
###### 206 | ### Do wart ein michel dringen vn– grozer swerte chlanch ### da ir ingesinde zvo zein ander dranch ### do versvochten sich di rechen beide deste baz ### di scar begvnden wichen sich hvop da groezlicher haz
###### 207 | ### Dem vogte von den Sahsen was daz wol geseit ### sin brvoder was gevangen daz was im harte leit ### wol wesser daz ez tæte daz Siglinde chint ### man zeh ez Gernote vil wol ervant erz sint [300a]
###### 208 | ### <· i> slege Livdegers di waren also starch ### daz <Sivride> vnder sætele strvochte daz march ### do sich daz ross erholte der chvene Sivrit ### der gewan in dem stvrme einen vreislichen sit
###### 209 | ### Des half im wol Hagene vn– ovch Gernot ### Danchwart vn– Volker des lag ir vil da tot ### Sindolt vn– Hvnolt vn– Oertwin der degen ### di chvnden in dem strite cem tode manegen nider legen
###### 210 | ### In stvrme vngesceiden waren di fvrsten her ### do sach man vber helme vligen manegen ger ### dvrch di liehten schilde von der helde hant ### man sah da var nach blvote vil mangen herlichen rant
###### 211 | ### <· n> dem starchen stvrme erbeizte manech man ### nider von den rossen ein ander liefen an ### Sivrit der vil chvene vn– ovch Livdeger ### man sach da scefte vliegen vnd manegen scærpfen ger
###### 212 | ### Dvo flovch daz schilt gespenge von Sivrids hant ### <den> sig gedaht erwerben der helt von Niderlant ### an den chvenen Sahsen der man vil wnder sach ### hei waz da liehter ringe der chvene Danchwart cebrach
###### 213 | ### Do het der herre Livdeger v^f einme schilde erchant ### gemalet eine chrone vor Sivrids hant ### wol <wesser> er daz ez wære der chreftige man ### der helt zvo sinen friwenden do lvote rvefen began
###### 214 | ### Gelovbet ivch des stvrmes alle mine man ### svn den Sigmvndes ich hie gesehn han ### Sivriden den starchen han ich hie bechant ### in hat der vbele tivuel her cen Sahsen gesant
###### 215 | ### Die vanen hiez er lazen in dem stvrme <nider> ### vrides er do gerte des werte man in sider ### doch mvos er werden gisel in Gvnthers lant ### daz het an im betwngen des chvenen Sivrides hant
| ### <Hit> gemeinem rate so liezen si den strit ### dvrchel vil der helme vnd ovch der schilde wit ### si leiten von den handen swaz so man der vant ### di trvogen blvotes varwe von der Bvrgonden hant
###### 217 | ### Si viengen swen si wolden des heten si gewalt ### Gernot vnd Hagene di rechen vil balt ### die wnden hiezen baren si fvorten mit in dan ### gevangen zvo dem Rine fvnf hvndert werlicher man
###### 218 | ### Die Sigelosen rechen ce Tenemarche riten ### done heten ovch di Sahsen so hohe niht gestriten ### daz man in lobes iæhe daz was den helden leit ### do wrden ovch di veigen von vriwenden sere gechleit
| ### <Si> hiezen daz gewafen wider sovmen an den Rin ### ez hete wol geworben mit den helden sin ### Sivrit der reche der hetez gvot getan ### des [300b] im iehen mvosen alle Gvnthers man
###### 220 | ### Gegen Wormez sande der herre Gernot ### heim zvo sime lande den vriwenden er enbot ### wie gelvngen wære im vn– sinen man ### ez heten die vil chvenen wol nach ern getan
| ### <Die> garzvone liefen von den wart ez geseit ### da frevten sich vor liebe di ê da heten leit ### dirre lieben mære di in da waren chomn ### da wart von edelen frovwen. michel vragen vernomn
###### 222 | ### wie gelvngen wære des richen kvneges man ### man hiez der boten einen fver Chrimilde gan ### daz gescach vil tovgen iane torstes vmber lvot ### wan si hete dar vnder ir vil liebez hercen trvot
###### 223 | ### Do si den boten chomende zir chemenaten sach ### Chrimhilt div scoene vil gvetlichen sprach ### nv sag an liebiv mære ia gib ich dir min golt ### tvost dvz ane liegen. ich wil dir immer wesen holt
###### 224 | ### Wie sciet voz dem strite min brvoder Gernot ### vn– ander mine friwenden ist vns iht maneger tot ### oder wer tet da daz beste daz solt dv mir sagn ### do sprach der bote sciere wir heten ninder cheinen zagn
| ### Ze ernste vn– ce strite reit niemn also wol ### vil edeliv kvneginne sit ichz iv sagen sol ### so der gast vil edele vozer Niderlant ### da worhte michel wnder des chvenen Sivrides hant
###### 226 | ### Swaz di rechen alle instrite hant getan ### Danchwart vn– Hagene vn– ander skvneges man ### swaz si striten nach ern daz ist gar ein wint ### vnz eine an Sivriden des kvnec Sigmvnds kint
###### 227 | ### Si frvmten in dem stvrme der helde vil erslagn ### doch moehte iv daz wnder niemn wol gesagn ### waz da worhte Sivrit swen er ce strite reit ### den frovwen an ir magen tet er div groezlichen leit
###### 228 | ### Ovch mvoste da belibn maneger frovwen trvt ### sine slege man <horte> vof helmen also lvt ### daz si von wnden brahten daz fliezende blvot ### erst an allen tvgenden ein riter chvn vnde gvot
| ### <Swaz> da hat begangen von Mecen Oertwin ### swaz er ir moht erlangen mit dem swerte sin ### di mvosen wnt belibn oder meistech tot ### da tet iwer brvoder die aller groezisten not
###### 230 | ### div immer inden stvermen chvnde sin gescehn ### man mvoz der warheite den vz erwelten iehn ### di stolcen Bvrgonden habent so gevaren ### daz si vor allen scanden ir ere chvnnen wol bewarn [301a]
###### 231 | ### Man sach da vor ir handen vil manegen satel bloz ### da von liehten swerten daz velt so lvote erdoz ### di rechen von dem Rine di habent so geriten ### daz ez ir vianden wære bezer vermiten
| ### <Die> chvenen Tronegære di frvmtn groziv leit ### do mit volches chreften daz her ce samne reit ### da frvmte manegen toten des chvenen Hagenen hant ### des vil cesagene wære her ceBvrgonden lant
###### 233 | ### Sindolt vn– Hvnolt di Gernotes man ### vn– Rvomolt der chvene di hant so vil getan ### daz ez Livdegere mag immer wesen leit ### daz er den dinen magen ze Rine hete widerseit
###### 234 | ### Strit den aller hoehsten der inder da gescach ### ce ivngest vn– cem ersten den ieman gesach ### den tet vil willechliche div Sivrides hant ### er bringet riche gisel in daz Gvnthers lant
###### 235 | ### Die twanch mit sinen ellen der wætliche man ### des ovch der kvnec Livdegast mvoz den scaden han ### vn– ovch von Sahsen lande sin brvoder Livdeger ### nv hoeret miniv mære edeliv chvneginne her
###### 236 | ### Si hat gevangen beide div Sivrids hant ### nie so manegen gisel man braht indizze lant ### so von sinen schvlden nv chvmt an den Rin ### ir chvnden disiv mære nimmer lieber sin
| ### Man bringet der gesvnden fvnf hvndert oder baz ### vnt der verch wnden frovwe wizzet daz ### wol ahtzech rôte bâre her in vnser lant ### di meistech hat verhovwen des starchen Sivrids hant
###### 238 | ### Die dvrch vbermveten widersagten an den rin ### die mvezen nv gevangen di Gvnthers sin ### die bringet man mit vrevden her in dizze lant ### do erblvete ir liehtiv varwe do si div mær reht ervant
| ### <Ir> scoenez antlvzze daz wart rosen rot ### do mit liebe was gesceiden voz der grozen not ### der wætliche reche Sivrit der ivnge man ### si frevte ovch sich ir friwende daz was von scvlden getan
###### 240 | ### Do sprach div minnechliche dv hast mir wol geseit ### dv solt habn dar vmbe ce miete richiv chleit ### vn– zehen march von golde die heiz ich dir tragn ### des mach man soelhiv <mere> richen frovwen gerne sagn
###### 241 | ### Man gab im sine miete daz golt vn– ovch div chleit ### do gie an div venster vil manec scoeniv meit ### si warten v^f di strazen riten man do vant ### vil der hoch gemvoten in der <Bvrgonden> lant
###### 242 | ### Da chomn die gesvnden di wnden taten sam ### si mohten grvezen hoeren von friwenden ane scam ### der wirt gein sinen gesten vil vroeliche reit ### mit vrevden was verendet daz sin vil groez [301b] liche leit
| ### <Do> enpfie er wol di sine die vremden tet er sam ### wan dem richen kvnege anders niht gezam ### wan danchen gvetliche den di im waren chomn ### daz si den sig nah eren in stvrme heten genomn
###### 244 | ### Gvnther bat im mære von sinen vriwenden sagn ### wer im an der reise ce tode wær erslagn ### do het er vloren niemn niwan sehzec man ### verchlagen man di mvose so sit nach helden <was> getan
###### 245 | ### Die gesvnden brahten cerhovwen manegen rant ### von helme vil verscroten in Gvnthers lant ### daz volch erbeizte nidere fvr des kvnges sal ### ce liebem antpfange man horte vroelichen scal
###### 246 | ### Do hiez man herbergen di rechen in di stat ### der chvnech siner geste vil scone pflegen bat ### er hiez der wnden hveten vn– scaffen gvot gemach ### wol man sine tvgende an sinen vianden sach
| ### Er sprach ce Livdegaste nv sit mir willechomn ### ich han von iwern scvlden vil grozen scaden genomn ### der wirt mir nv vergolten ob ich gelvcke han ### got lone minen vriwenden si hant liebe getan
###### 248 | ### Ir mvgt in gerne danchen sprach do Livdeger ### also hoher gisel. gewan nie kvnec mer ### vmbe scoene hvote wir gebn michel gvot ### <dazir> genædechliche an iwern vianden tvot
###### 249 | ### Ich wil ivch beide lazen sprach er ledech gen ### daz mine viande hie bi mir besten ### des wil ich habn pvergen daz si miniv lant ### iht rv^men ane hvlde des bot Livdeger di hant
| ### Man brahte si ce rwoe vn– scvof in ir gemach ### den wnden man gebettet vil gvetlichen sach ### man schancte den gesvnden met vn– gvoten win ### do chvnde daz gesinde nimmer vroelicher sin
###### 251 | ### Ir cerhovwen schilde behalten man do trvoch ### vil blvotiger sætele der was da genvoch ### di hiez man verbergen da weinten niht div wip ### da chom her mvede maneges gvoten riters lip
| ### Der kvnec pflach siner geste vil groezliche wol ### der vremden vn– der chvnden div lant waren vol ### er bat der sere wnden vil gvetliche pflegn ### do was ir vbermveten vil harte ringe gelegn
###### 253 | ### Die ercenie chvnden den bot man richen solt ### silber ane wage dar zvo daz liehte golt ### daz si die helde nerten nach der strites not ### darzvo der kvnec den gêsten gabe groezlichen bot
###### 254 | ### Die wider heim cehvse heten reise mvot ### di bat man noch beliben also man vriwenden tvot ### der kvnech do gie ce rate wier lonte sinen man ### si heten sinen willen nach grozen êrn getan
| ### <Do> sprach der herre Gernot man sol si riten lan ### vber sechs wochen si in daz [302a] chvnt getan ### daz si chomn widere ce einer hohgecit ### so ist ir maneger geheilet der nv vil sere wnder lit
###### 256 | ### Do gert ovch vrlovbes Sivrit von Niderlant ### do der kvnec Gvnther den willen sin ervant ### er bat in minnechliche noch bi im bestan ### niwan dvrch sine swester scoene <sone> wær ez nimmer getan
| ### Dar zvo was er ce riche daz er iht næme solt ### er het daz wol verdienet der kvnec was im holt ### sam waren sine mage di heten daz gesehn ### waz von sinen chreften in dem strite was gescehn
###### 258 | ### Dvrch der scoenen willen gedahter noch bestan ### ob er si gesehen moehte sit wart ez getan ### wol nach sinen willen wart im div maget bechant ### sit reit er vroeliche in daz Sigmvnds lant
| ### <Der> wirt hiez ce allen citen riterscefte pflegn ### daz tet do willechlichen vil manech ivnger degn ### di wile hiez er sideln vor Wormez v^f den sant ### den di im chomn solden zvo der bvrgonden lant
###### 260 | ### In den selbn citen do si nv solden chomn ### do het div scoene Chrimhilt div mære wol vernomn ### er wolde hohgecite dvrch liebe vriwende han ### do wart vil michel vlizen von scoenen frovwen getan
###### 261 | ### mit wæte vn– mit gebende daz si da solden tragn ### vote div vil riche div mære horte sagn ### von den stolzen rechen di da solden chomn ### do wart v^z der valde vil richer chleider <genomn>
###### 262 | ### Dvrch ir chinde liebe hiez si bereiten chleit ### da mite wart gecieret vil manec frovwe vn– manech meit ### vn– vil der ivngen rechen voz Bvrgonden lant ### ovch hiez si vil den vremden prveuen herlich gewant

<<< Übersicht <<< vorige Seite nächste Seite >>>